Learn R Programming

evola (version 1.0.7)

addZeros: Function to add zeros before and after a numeric vector to have the same number of characters.

Description

Function to add zeros before and after a numeric vector to have the same number of characters.

Usage

addZeros(x, nr=2)

Value

$res

a matrix

Arguments

x

Numeric vector.

nr

number of digits to keep to the right.

Details

A simple apply function to make a matrix of one row and nc columns.

References

Giovanny Covarrubias-Pazaran (2024). evola: a simple evolutionary algorithm for complex problems. To be submitted to Bioinformatics.

See Also

evolafit -- the core function of the package

Examples

Run this code

addZeros(5)

Run the code above in your browser using DataLab