Learn R Programming

evola (version 1.0.7)

pareto: plot the change of values across iterations

Description

plot for monitoring.

Usage

pareto(object, scaled=TRUE,pch=20, xlim, ...)

Value

vector of plot

Arguments

object

model object returned by "evolafit"

scaled

a logical value to specify the scale of the y-axis (gain in merit).

pch

symbol for plotting points as desribed in par

xlim

upper and lower bound in the x-axis

...

Further arguments to be passed to the plot function.

Author

Giovanny Covarrubias

See Also

plot, evolafit