powered by
Function to add zeros before and after a numeric vector to have the same number of characters.
addZeros(x, nr=2)
a matrix
Numeric vector.
number of digits to keep to the right.
A simple apply function to make a matrix of one row and nc columns.
Giovanny Covarrubias-Pazaran (2024). evola: a simple evolutionary algorithm for complex problems. To be submitted to Bioinformatics.
evolafit -- the core function of the package
evolafit
addZeros(5)
Run the code above in your browser using DataLab