| drift | R Documentation |
This function takes a population and the simulation parameters from a .Pop class and calculates the current frequencies of the positive alleles for each trait.
drift(pop, simParam, solution=NULL, traits=1)
pop |
an object of class |
simParam |
the simulation parameters stored in the evolaMod object. |
solution |
an alternative RRBLUP solution so the frequencies of positive alleles are calculated for a given SNP chip. If NULL the frequencies are calculated for the real QTLs. |
traits |
traits considered. |
A simple apply function to get all the QTLs, segregation sites, positive alleles and frecuency of the positive allele for each trait in a population.
a matrix
Giovanny Covarrubias-Pazaran (2024). evola: a simple evolutionary algorithm for complex problems. To be submitted to Bioinformatics.
evolafit – the core function of the package
#Create founder haplotypes
founderPop = quickHaplo(nInd=10, nChr=1, segSites=30)
#Set simulation parameters
SP = SimParam$new(founderPop)
SP$addTraitA(10)
SP$setVarE(h2=0.5)
SP$addSnpChip(15)
#Create population
pop = newPop(founderPop, simParam=SP)
# drift for QTLs
drift(pop, simParam = SP )
ans = RRBLUP(pop, simParam=SP)
# drift for average allelic effects
drift(pop, simParam = SP, solution = ans)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.